==> fr-aster-9.3.0.1.tbz: aster/STA9.3/bibpyt/Messages/calculel.py <==
#@ MODIF calculel Messages  DATE 19/05/2008   AUTEUR PELLET J.PELLET 
# -*- coding: iso-8859-1 -*-
#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2007  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ======================================================================

def _(x) : return x

cata_msg = {

2 : _("""
Erreur Utilisateur :
 Quand on utilise AFFE_CHAR_CINE/EVOL_IMPO, c'est le champ de l'evol_xxx correspondant
 au 1er instant qui impose sa "loi" : tous les ddls de ce champ seront imposs pour tous
 les instants du calcul.

 Malheureusement, on ne trouve pas un ddl dans l'evol_xxx %(k1)s :
   instant : %(r1)f  noeud : %(i1)d  cmp : %(k2)s

Risques & conseils :
 Assurez-vous que l'volution impose %(k1)s concerne les memes ddls pour tous les instants.
"""),

3 : _("""
 la grandeur :  %(k1)s  n existe pas dans le catalogue des grandeurs.
"""),

4 : _("""
 incoherence des maillages : %(k1)s  et  %(k2)s
"""),

5 : _("""
 Erreur de programmation (ou d'utilisation ?) :
   Le changement de discrtisation : %(k1)s n'est pas encore programm.
 Risques et conseils :
   Il y a peut-etre une demande d'volution  mettre ...
"""),

6 : _("""
 Erreur d'utilisation :
   On n'arrive pas  construire correctement le champ contenant le nombre de sous-points
   des lments finis (coques multi-couches, tuyaux, poutre multi-fibres, ...)  du modle %(k1)s.

 Risques & conseils :
   Cette erreur intervient lorsque l'on ne dfinit pas TOUTES les caractristiques lmentaires
   dans le meme AFFE_CARA_ELEM.
   Pour les commandes de calcul, il ne faut qu'un seul MODELE et qu'un seul CARA_ELEM.
"""),

8 : _("""
 sur la maille %(k1)s le calcul est thermo mcanique. Or il manque la temprature de rfrence.
 On ne peut donc pas calculer de dformation thermique.
"""),

9 : _("""
 Erreur d'utilisation dans AFFE_CHAR_CINE :
   Aucun des ddls que l'on souhaite bloquer n'appartient au modle.
   La charge cinmatique produite est donc vide.

 Risques & Conseils :
   Vrifier le nom des ddls ports par les noeuds des lments de votre modle.
"""),

11 : _("""
 le mode_local:  %(k1)s  ne doit pas etre vecteur ou matrice.
"""),

12 : _("""
 le mode_local:  %(k1)s  ne doit pas etre "diff__".
"""),

14 : _("""
  incompatibilite des type_champ ("elga"/"elno")  pour l option :  %(k1)s  entre les 2 type_elem :  %(k2)s  et  %(k3)s
"""),

15 : _("""
 sur la maille %(k1)s le calcul est thermo mcanique. Or il manque le parametre matriau
 %(k2)s . On ne peut donc pas calculer de dformation thermique.
"""),

16 : _("""
 type de maille indisponible
"""),

17 : _("""
 type de champ inconnu
"""),

18 : _("""
 les parties relle et imaginaire du champ  assembler ne sont pas du mme type
 l'un est un CHAM_NO et l'autre un CHAM_ELEM
"""),

20 : _("""
 le champ de grandeur  %(k1)s  ne respecte pas le format xxxx_r
"""),

21 : _("""
 les champs rel et imaginaire  assembler ne contiennent pas la mme grandeur
"""),

22 : _("""
 problme dans le catalogue des grandeurs simples
 la grandeur %(k1)s  ne possde pas le mme nombre de champs que son homologue complexe %(k2)s
"""),

23 : _("""
 problme dans le catalogue des grandeurs simples
 la grandeur  %(k1)s  ne possde pas les mmes champs que son homologue complexe  %(k2)s
"""),

24 : _("""
 les champs  assembler n'ont pas la mme longueur
"""),

27 : _("""
 CHAM_ELEM  combiner incompatible
"""),

29 : _("""
 option inconnue au catalogue :  %(k1)s
"""),

30 : _("""
  -> Le TYPE_ELEMENT %(k1)s  ne sait pas encore calculer l'OPTION:  %(k2)s.
     On ne calcule donc rien sur les lments de ce type.

  -> Risque & Conseil :
     Vrifiez que l'option incompltement calcule est bien une option de post-traitement
     et que le dficit de calcul n'entraine pas de rsultats faux.
"""),

31 : _("""
  la temprature n'est pas correctement renseigne
"""),

34 : _("""
 le calcul de l'option :  %(k1)s
 n'est possible pour aucun des types d'lments du LIGREL.
"""),

37 : _("""
 Erreur dans la lecture des CHAR_CINE ou dans les CHAR_CINE
"""),

38 : _("""
 la carte concerne aussi des mailles tardives qui sont oublies
"""),

42 : _("""
 Erreur Programmeur:
 Incohrence fortran/catalogue
 TYPE_ELEMENT :  %(k1)s
 OPTION       :  %(k2)s
 La routine texxxx.f correspondant au calcul lmentaire ci-dessus est buggue
 Elle crit en dehors de la zone alloue au paramtre (OUT) %(k3)s.

"""),

47 : _("""
  le CHAM_ELEM:  %(k1)s  n'existe pas.
"""),

48 : _("""
 le CHAM_ELEM: %(k1)s  n'a pas le mme nombre de composantes dynamiques sur tous ses lments.
"""),

49 : _("""
 le CHAM_ELEM : %(k1)s a des sous-points.
"""),

52 : _("""
 La composante: %(k1)s  n'appartient pas  la grandeur: %(k2)s
 Champ : %(k4)s
"""),

53 : _("""
 Option : %(k1)s  inexistante dans les catalogues.
 Champ : %(k4)s
"""),

54 : _("""
 Le paramtre:  %(k1)s  de l'option:  %(k2)s  n'est pas connu des TYPE_ELEM du LIGREL:  %(k3)s
 Champ : %(k4)s
"""),

55 : _("""
 Erreur utilisateur :
   On cherche  crer un CHAM_ELEM mais sur certains points, on ne trouve pas la composante : %(k1)s
   Champ : %(k4)s
 Risques & conseils :
   Si la commande que vous excutez comporte le mot cl PROL_ZERO='OUI', vous devriez peut-etre l'utiliser.
"""),

56 : _("""
 Le LIGREL contient des mailles tardives
 Champ : %(k4)s
"""),

57 : _("""
 Nombres de points diffrents pour la maille:  %(k1)s
 CHAM_ELEM de :  %(k2)s
 Champ : %(k4)s
"""),

58 : _("""
 Il manque la composante : %(k1)s  sur la maille : %(k2)s
 Champ : %(k4)s
"""),

67 : _("""
 grandeur:  %(k1)s  inconnue au catalogue.
"""),

68 : _("""
 numro de maille invalide     :  %(k1)s  (<1 ou >nbma)
"""),

69 : _("""
 numro de point invalide      :  %(k1)s  (<1 ou >nbpt)
 pour la maille                :  %(k2)s
"""),

70 : _("""
 numro de sous_point invalide :  %(k1)s  (<1 ou >nbspt)
 pour la maille                :  %(k2)s
 pour le point                 :  %(k3)s
"""),

71 : _("""
 numro de composante invalide :  %(k1)s  (<1 ou >nbcmp)
 pour la maille                :  %(k2)s
 pour le point                 :  %(k3)s
 pour le sous-point            :  %(k4)s
"""),

91 : _("""
 incohrence des familles de points de Gauss pour la maille  %(k1)s
 ( %(k2)s / %(k3)s )
"""),

92 : _("""
 type scalaire du CHAM_NO :  %(k1)s  non rel.
"""),

93 : _("""
 type scalaire du NUME_DDL :  %(k1)s  non rel.
"""),

99 : _("""
 melange de CHAM_ELEM_S et CHAM_NO_S
"""),

}

==> fr-aster-9.4.0.2.tbz: aster/STA9.4/bibpyt/Messages/calculel.py <==
#@ MODIF calculel Messages  DATE 07/10/2008   AUTEUR PELLET J.PELLET 
# -*- coding: iso-8859-1 -*-
#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2007  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ======================================================================

def _(x) : return x

cata_msg = {

1 : _("""
Erreur Utilisateur :
 En cherchant  projeter 1 noeud sur une maille, l'algorithme de Newton choue.
 Le problme vient probablement de la mauvaise qualit de la maille.
 Maille "coupable" : %(k1)s

Risques & conseils :
 Vrifiez la maille incrimine (numrotation et gomtrie de ses noeuds, ...)
"""),

2 : _("""
Erreur Utilisateur :
 Quand on utilise AFFE_CHAR_CINE/EVOL_IMPO, c'est le champ de l'evol_xxx correspondant
 au 1er instant qui impose sa "loi" : tous les ddls de ce champ seront imposs pour tous
 les instants du calcul.

 Malheureusement, on ne trouve pas un ddl dans l'evol_xxx %(k1)s :
   instant : %(r1)f  noeud : %(i1)d  cmp : %(k2)s

Risques & conseils :
 Assurez-vous que l'volution impose %(k1)s concerne les memes ddls pour tous les instants.
"""),

3 : _("""
 la grandeur :  %(k1)s  n existe pas dans le catalogue des grandeurs.
"""),

4 : _("""
 incoherence des maillages : %(k1)s  et  %(k2)s
"""),

5 : _("""
 Erreur de programmation (ou d'utilisation ?) :
   Le changement de discrtisation : %(k1)s n'est pas encore programm.
 Risques et conseils :
   Il y a peut-etre une demande d'volution  mettre ...
"""),

6 : _("""
 Erreur d'utilisation :
   On n'arrive pas  construire correctement le champ contenant le nombre de sous-points
   des lments finis (coques multi-couches, tuyaux, poutre multi-fibres, ...)  du modle %(k1)s.

 Risques & conseils :
   Cette erreur intervient lorsque l'on ne dfinit pas TOUTES les caractristiques lmentaires
   dans le meme AFFE_CARA_ELEM.
   Pour les commandes de calcul, il ne faut qu'un seul MODELE et qu'un seul CARA_ELEM.
"""),

7 : _("""
 Erreur de maillage :
   La maille %(k1)s de type %(k2)s est trop distordue.
   Le jacobien de la transformation gomtrique n'a pas le meme signe sur tous les
   points de Gauss.

 Risques & conseils :
   Le maillage a-t-il t produit par un mailleur ?
   La connectivit respecte-elle bien la convention Aster ?
"""),

8 : _("""
 sur la maille %(k1)s le calcul est thermo mcanique. Or il manque la temprature de rfrence.
 On ne peut donc pas calculer de dformation thermique.
"""),

9 : _("""
 Erreur d'utilisation dans AFFE_CHAR_CINE :
   Aucun des ddls que l'on souhaite bloquer n'appartient au modle.
   La charge cinmatique produite est donc vide.

 Risques & Conseils :
   Vrifier le nom des ddls ports par les noeuds des lments de votre modle.
"""),

11 : _("""
 le mode_local:  %(k1)s  ne doit pas etre vecteur ou matrice.
"""),

12 : _("""
 le mode_local:  %(k1)s  ne doit pas etre "diff__".
"""),

14 : _("""
  incompatibilite des type_champ ("elga"/"elno")  pour l option :  %(k1)s  entre les 2 type_elem :  %(k2)s  et  %(k3)s
"""),

15 : _("""
 sur la maille %(k1)s le calcul est thermo mcanique. Or il manque le parametre matriau
 %(k2)s . On ne peut donc pas calculer de dformation thermique.
"""),

16 : _("""
 type de maille indisponible
"""),

17 : _("""
 type de champ inconnu
"""),

18 : _("""
 les parties relle et imaginaire du champ  assembler ne sont pas du mme type
 l'un est un CHAM_NO et l'autre un CHAM_ELEM
"""),

20 : _("""
 le champ de grandeur  %(k1)s  ne respecte pas le format xxxx_r
"""),

21 : _("""
 les champs rel et imaginaire  assembler ne contiennent pas la mme grandeur
"""),

22 : _("""
 problme dans le catalogue des grandeurs simples
 la grandeur %(k1)s  ne possde pas le mme nombre de champs que son homologue complexe %(k2)s
"""),

23 : _("""
 problme dans le catalogue des grandeurs simples
 la grandeur  %(k1)s  ne possde pas les mmes champs que son homologue complexe  %(k2)s
"""),

24 : _("""
 les champs  assembler n'ont pas la mme longueur
"""),

27 : _("""
 CHAM_ELEM  combiner incompatible
"""),

29 : _("""
 option inconnue au catalogue :  %(k1)s
"""),

30 : _("""
  -> Le TYPE_ELEMENT %(k1)s  ne sait pas encore calculer l'OPTION:  %(k2)s.
     On ne calcule donc rien sur les lments de ce type.

  -> Risque & Conseil :
     Vrifiez que l'option incompltement calcule est bien une option de post-traitement
     et que le dficit de calcul n'entraine pas de rsultats faux.
"""),

31 : _("""
  la temprature n'est pas correctement renseigne
"""),

34 : _("""
 le calcul de l'option :  %(k1)s
 n'est possible pour aucun des types d'lments du LIGREL.
"""),

35 : _("""
 Erreur utilisateur :
  On essaye de fusionner 2 cham_elem mais ils n'ont pas le meme nombre
  "points" (noeuds ou points de Gauss) pour la maille numro : %(i1)d.
  Nombres de points :  %(i2)d et %(i3)d
"""),

36 : _("""
 Erreur utilisateur :
  On essaye de fusionner 2 cham_elem mais ils n'ont pas le meme nombre
  de "sous-points" (fibres, couches, ...) pour la maille numro : %(i1)d.
  Nombres de sous-points :  %(i2)d et %(i3)d
"""),

37 : _("""
 Erreur dans la lecture des CHAR_CINE ou dans les CHAR_CINE
"""),

38 : _("""
 la carte concerne aussi des mailles tardives qui sont oublies
"""),

42 : _("""
 Erreur Programmeur:
 Incohrence fortran/catalogue
 TYPE_ELEMENT :  %(k1)s
 OPTION       :  %(k2)s
 La routine texxxx.f correspondant au calcul lmentaire ci-dessus est buggue
 Elle crit en dehors de la zone alloue au paramtre (OUT) %(k3)s.

"""),

47 : _("""
  le CHAM_ELEM:  %(k1)s  n'existe pas.
"""),

48 : _("""
 le CHAM_ELEM: %(k1)s  n'a pas le mme nombre de composantes dynamiques sur tous ses lments.
"""),

49 : _("""
 le CHAM_ELEM : %(k1)s a des sous-points.
"""),

52 : _("""
 La composante: %(k1)s  n'appartient pas  la grandeur: %(k2)s
 Champ : %(k4)s
"""),

53 : _("""
 Option : %(k1)s  inexistante dans les catalogues.
 Champ : %(k4)s
"""),

54 : _("""
 Le paramtre:  %(k1)s  de l'option:  %(k2)s  n'est pas connu des TYPE_ELEM du LIGREL:  %(k3)s
 Champ : %(k4)s
"""),

55 : _("""
 Erreur utilisateur :
   On cherche  crer un CHAM_ELEM mais sur certains points, on ne trouve pas la composante : %(k1)s
   Champ : %(k4)s
 Risques & conseils :
   Si la commande que vous excutez comporte le mot cl PROL_ZERO='OUI', vous devriez peut-etre l'utiliser.
"""),

56 : _("""
 Le LIGREL contient des mailles tardives
 Champ : %(k4)s
"""),

57 : _("""
 Erreur Utilisateur :
   On cherche  transformer un champ simple en cham_elem.
   Le nombre de "points" (points de Gauss ou noeuds) du champ simple (%(i1)d) est
   diffrent du nombre de points attendu pour le cham_elem (%(i2)d) :
     - maille              :  %(k1)s
     - nom du cham_elem    :  %(k4)s
     - nom du champ simple :  %(k5)s

"""),

58 : _("""
 Il manque la composante : %(k1)s  sur la maille : %(k2)s
 Champ : %(k4)s
"""),

67 : _("""
 grandeur:  %(k1)s  inconnue au catalogue.
"""),

68 : _("""
 numro de maille invalide     :  %(k1)s  (<1 ou >nbma)
"""),

69 : _("""
 numro de point invalide      :  %(k1)s  (<1 ou >nbpt)
 pour la maille                :  %(k2)s
"""),

70 : _("""
 numro de sous_point invalide :  %(k1)s  (<1 ou >nbspt)
 pour la maille                :  %(k2)s
 pour le point                 :  %(k3)s
"""),

71 : _("""
 numro de composante invalide :  %(k1)s  (<1 ou >nbcmp)
 pour la maille                :  %(k2)s
 pour le point                 :  %(k3)s
 pour le sous-point            :  %(k4)s
"""),

91 : _("""
 incohrence des familles de points de Gauss pour la maille  %(k1)s
 ( %(k2)s / %(k3)s )
"""),

92 : _("""
 type scalaire du CHAM_NO :  %(k1)s  non rel.
"""),

93 : _("""
 type scalaire du NUME_DDL :  %(k1)s  non rel.
"""),

99 : _("""
 melange de CHAM_ELEM_S et CHAM_NO_S
"""),

}
